@@ -101,8 +101,8 @@ public:
         bpp8
     };
 
-    explicit VncClientThread(QObject *parent = 0);
-    ~VncClientThread();
+    explicit VncClientThread(QObject *parent = nullptr);
+    ~VncClientThread() override;
     const QImage image(int x = 0, int y = 0, int w = 0, int h = 0);
     void setImage(const QImage &img);
     void emitUpdated(int x, int y, int w, int h);
